Zope Windows Binary Post-Installation QuickStart

Welcome to Zope, a high-performance object-oriented platform for building dynamic Web applications. Here are some quick pointers to get you started:

- If you've launched your Zope instance, and you'd like to get started right away, you can go directly to the Zope Management Interface. Use the username "admin" and the password you specified during installation process to log in. Please be patient as it may take a few moments for your Zope instance to start before you can connect to it successfully.

- If you've not started your Zope instance, you can do so by choosing the "Run Zope" command from the Zope program group in your Start Menu. If you installed Zope as a Windows 'service' (NT/2000/XP only), you may use the Control Panel --> Administrative Tools --> Services applet to start your Zope instance as well. The service will be named "Zope instance at <instance home directory name>".

- If you've not yet created a Zope instance, perform the following steps to do so:

  1. Visit a console window (type "cmd" (NT/2000/XP) or "command" (95/98/ME) in the Run box from the Start Menu).
  2. Change to the "bin" directory directory of your Zope software home using the "cd" command, e.g. "cd c:\Program Files\Zope-2.7\bin".
  3. Type "python.exe mkzopeinstance.py"
  4. Follow the instructions provided by 'mkzopeinstance.py'.

  To start the resulting instance, visit the directory you specified during your interaction with 'mkzopeinstance.py' and type "bin\runzope.bat".

- For the most complete "starter" documentation, Read The Fine Manual. This document guides you through the whole process of learning Zope, from logging in for the first time to creating your own web applications.

- For further documentation, go to the main Documentation Overview on Zope.org. Here you will find pointers to official and community contributed documentation.

- To get personal assistance with Zope, look at the various Mailing Lists about Zope. The Mailing Lists are where you can get quick, accurate, friendly help from a large community of Zope users from around the world.

- If you wish, you can find out about Zope Corporation, the publishers of Zope.